<?php
/**
 *
 * Plugin Name:       Editor Inline Code
 * Plugin URI:        https://wordpress.org/plugins/editor-inline-code/
 * Description:       Add Code Sample Plugin of TinyMCE. you can syntax highlight the code in TinyMCE Editor and display it.
 * Version:           1.0.1
 * Author:            hana
 * Author URI:        https://15-source.com/release/editor-inline-code/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       editor-inline-code
 * Domain Path:       /languages
 */

// exit if accessed directly
if( ! defined( 'ABSPATH' ) ) exit;

// check if class already exists
if( !class_exists('Editor_Inline_Code') ) :

class Editor_Inline_Code {
	private static $instance = null;

	// plugin info
	private $plugins;
	// plugin option
	private $options;
	// path
	private $assets;
	private $admin;
	private $default;
	private $dist;
	private $src;
	private $tinymce;
	private $prism;
	// values
	private $theme_values;
	// private $lang_values



	/**
	 * __construct
	 *
	 * Description
	 *
	 * @type	function
	 * @date
	 * @since	1.0.0
	 *
	 * @param	none
	 * @return	void
	 */
	public function __construct()
	{
		/*
			load text domain
		*/
		load_plugin_textdomain(
			'editor-inline-code',
			false,
			plugin_basename( dirname( __FILE__ ) ) . '/languages'
		);

		/*
			vars
		*/
		$this->plugins = array(
			'version'	=> '1.0.0',
			'url'		=> plugin_dir_url( __FILE__ ),
			'path'		=> plugin_dir_path( __FILE__ ),
			'assets' => array(
				'url' => plugin_dir_url( __FILE__ ).'assets/'
			)
		);
		// for assets
		$this->assets = array(
			'admin' => array(
				'url' => $this->plugins['assets']['url'].'admin/'
			),
			'default' => array(
				'url' => $this->plugins['assets']['url'].'default/'
			)
		);
			// for admin files
			$this->admin = array(
				// for editor js
				'js' => array(
					'url' => $this->assets['admin']['url'].'js/plugin.min.js'
				)
			);
				// for option page files
				$this->op = array(
					'css' => array(
						'url' => $this->assets['admin']['url'].'css/eic-settings.min.css'
					)
				);
			// for default files
			$this->default = array(
				// for default prism css & js
				'css' => array(
					'url' => $this->assets['default']['url'].'prism.min.css'
				),
				'js' => array(
					'url' => $this->assets['default']['url'].'prism.min.js'
				)
			);
		// dist dir. prism files by option
		$this->dist = array(
			'url' => $this->plugins['url'].'dist/',
			'path' => $this->plugins['path'].'dist/'
		);
			// prism output files
			$this->prism = array(
				'css' => array(
					//'url' => $this->dist['url'].'prism.min.css',
					//'path' => $this->dist['path'].'prism.min.css'
					'url' => $this->dist['url'].$this->get_cs_prism_css(),
					'path' => $this->dist['path'].$this->get_cs_prism_css()
				),
				'js' => array(
					//'url' => $this->dist['url'].'prism.min.js',
					//'path' => $this->dist['path'].'prism.min.js'
					'url' => $this->dist['url'].$this->get_cs_prism_js(),
					'path' => $this->dist['path'].$this->get_cs_prism_js()
				)
			);

		/* vendor before output */
		$this->src = array(
			'clipboard' => array(
				'js' => array(
					'path' => $this->plugins['path'].'vendor/clipboard/clipboard.min.js'
				)
			),
			'prism' => array(
				'core' => $this->plugins['path'].'vendor/prism/prism.js',
				'themes' => $this->plugins['path'].'vendor/prism/themes/',
				'langs' => $this->plugins['path'].'vendor/prism/components/',
				'plugins' => $this->plugins['path'].'vendor/prism/plugins/'
			),
			'tec' => array(
				'always' => array(
					'path' => $this->plugins['path'].'vendor/eic_original/eic_toolbar_always.css'
				),
				'styles' => array(
					'path' => $this->plugins['path'].'vendor/eic_original/eic_toolbar_styles.css'
				)
			)
		);
		// tinymce files
		$this->tinymce = array(
			'plugins' => array(
				'url' => $this->plugins['url'].'vendor/tinymce/plugins/',
				'filename' => 'plugin.min.js'
			),
			// load plugin files
			'load_plugins' => array(
				'codesample'
			)
		);
		// get DB setting value.
		$this->options = get_option( 'eic_settings' );
		// values
		$this->theme_values = array(
			'prism',
			'prism-dark',
			'prism-funky',
			'prism-okaidia',
			'prism-tomorrow',
			'prism-twilight',
			'prism-coy',
			'prism-solarizedlight'
		);

		/*
			action
		*/
		// Register method to be executed when plug-in is activated
		if ( function_exists('register_activation_hook') )
		{
			register_activation_hook(
				__FILE__,
				array( $this, 'activationHook' )
			);
		}// if
		// Register methods to be executed when the plug-in is stopped
		if ( function_exists('register_deactivation_hook') )
		{
			register_deactivation_hook(
				__FILE__,
				array( $this, 'deactivationHook' )
			);
		}// if
		// Register the method to be executed when the plugin is uninstalled
		if ( function_exists('register_uninstall_hook') )
		{
			register_uninstall_hook(
				__FILE__,
				'eic_uninstallHook'
			);
		}// if


		/*
			processing
		*/
		// at the beginning of all processing int action
		add_action( 'init', array($this, 'init_action') );
		// css & js for admin area
		add_action( 'admin_enqueue_scripts', array($this, 'admin_scripts_and_styles') );
		// css & js for front area
		add_action( 'wp_enqueue_scripts', array($this, 'front_scripts_and_styles') );
		// process when option saving
		add_action( 'update_option_eic_settings', array( $this, 'do_save_options' ), 10, 2 );
	}// function __construct()



	/**
	* activationHook
	*
	* Method executed when plug-in is activated
	*
	* @return void
	*/
	public function activationHook( $network_wide )
	{
		if ( is_multisite() && $network_wide )
		{// If multisite && activate from network
			$sites = get_sites();
			foreach ( $sites as $site ) {
				// switch blog
				switch_to_blog( $site->blog_id );
					$this->do_set_default();
				// return blog
				restore_current_blog();
			}// foreach

		} else {// singlesite or (multisite & activate from each blog)
			$this->do_set_default();
		}
	}
	/**
	* deactivationHook
	*
	* Method executed when the plug-in is stopped
	*
	* @return void
	*/
	public function deactivationHook()
	{
		// Processing when the plug-in is stopped
	}

	/**
	* do_set_default
	*
	* Set defualt value
	*
	* @return void
	*/
	private function do_set_default()
	{
		// only first activation
		if ( !get_option('eic_installed') )
		{
			// To restore the default. If there is a file.
			// $this->delete_dir ( $this->dist['path'] );

			// set default values
			$op_values = array();
			$op_values['eic_def_theme'] = 'prism';
			$op_values['eic_def_langs'] = array(
				'markup',
				'css',
				'javascript',
				'php'
			);
			$op_values['eic_def_s_code_lnumber'] = 'on';
			$op_values['eic_def_s_code_invisibles'] = 'on';
			$op_values['eic_def_s_tool_lang'] = 'on';
			$op_values['eic_def_s_toolbar'] = 'on';
			$op_values['eic_def_s_editor_toobar'] = 'on';
			$op_values['eic_def_toobar_style'] = 'on';

			// add default values
			add_option( 'eic_settings', $op_values );

			// set install flag
			update_option( 'eic_installed', '1' );
			// set default file flag
			update_option( 'eic_default', '1' );
		}
	}


	/**
	*  init_action
	*
	*  Set Action & Filter Hook
	*
	*  @type
	*  @date
	*  @since	1.0.0
	*
	*  @param	none
	*  @return void
	*/
	public function init_action()
	{
		// Attach a setting link to the plugin display
		add_filter( 'plugin_action_links_'.plugin_basename(__FILE__), array($this, 'add_action_links') );

		// Setting
		// Add a option page menu
		add_action( 'admin_menu', array( $this, 'add_plugin_menu' ) );
		// init option page
		add_action( 'admin_init', array( $this, 'page_init' ) );

		// load tinyMCE Plugin
		add_filter( 'mce_external_plugins', array($this, 'load_tinymce_plugins') );
		// add button
		add_filter( 'mce_buttons', array($this, 'add_mce_buttons') );
		// tinymce settings & Main processing
		add_filter( 'tiny_mce_before_init', array($this, 'tinymce_settings'), 1000 );
	}// function


	/**
	*  admin_scripts_and_styles
	*
	*  CSS & JS for Admin
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	$hook_suffix
	*  @return	void
	*/
	public function admin_scripts_and_styles( $hook_suffix )
	{
		if ( ! in_array($hook_suffix, array( "post-new.php", "post.php", "options-general.php")) )
		{
			return;
		}

		// for editor
		wp_enqueue_script(
			'editor-inline-code',
			$this->admin['js']['url'],
			array('jquery'),
			true
		);
	}// end function

	/**
	*  front_scripts_and_styles
	*
	*  CSS & JS for Front
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	$hook_suffix
	*  @return	void
	*/
	public function front_scripts_and_styles( $hook_suffix )
	{
		// CSS
		if ( get_option('eic_default') === '0' )
		{// css for option settings
			wp_enqueue_style(
				'prism-css',
				$this->prism['css']['url'],
				'',
				'1.0',
				'all'
			);
		} else {// css for default css
			wp_enqueue_style(
				'prism-css',
				$this->default['css']['url'],
				'',
				'1.0',
				'all'
			);
		}// if

		// JS
		if ( get_option('eic_default') === '0' )
		{// css for option settings
			wp_enqueue_script(
				'prism-js',
				$this->prism['js']['url'],
				array('jquery' ),
				'',
				true
			);
		} else {// css for default css
			wp_enqueue_script(
				'prism-js',
				$this->default['js']['url'],
				array('jquery' ),
				'',
				true
			);
		}
	}// end function


	/**
	*  add_action_links
	*
	*  Set Setting Link for plugin page
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	$links
	*  @return	$links
	*/
	public function add_action_links ( $links ) {
		$links[] = '<a href="options-general.php?page=eic_settings">'.__( 'Settings', 'editor-inline-code' ).'</a>';
		return $links;
	}


	/**
	*  load_tinymce_plugin
	*
	*  Load TinyMCE plugin file
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	$plugin_array(Array).
	*  @return	void
	*/
	public function load_tinymce_plugins( $plugin_array )
	{
		global $hook_suffix;

		if ( ! in_array($hook_suffix, array( "post-new.php", "post.php" )) )
		{
			return;
		}

		// tinymce plugins
		if ( ! isset($this->tinymce['load_plugins']) )
		{
			return;
		}
		// codesample
		$values = $this->tinymce['load_plugins'];
		foreach ( $values as $value ) {
			$url = $this->tinymce['plugins']['url'].$value.'/'.$this->tinymce['plugins']['filename'];
			$plugin_array[$value] = $url;
			return $plugin_array;
		}
	}// function




	/* *********************************************
		Option Page
	********************************************* */

	/**
	*  add_plugin_menu
	*
	*  Add menu for plugin option page in setting page
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	none
	*  @return	void
	*
	* add_menu_page( $page_title, $menu_title, $capability, $menu_slug, $function, $icon_url, $position );
	*
	* add_options_page(
	* 	$page_title : title for serring page
	* 	$menu_title : menu title
	* 	$capability : capability 'manage_options' or 'administrator' etc
	* 	$menu_slug : menu slug
	* 	$function : function name for setting page output
	* 	$icon_url : icon for menu
	* 	$position : position for menu 1 or 99 etc
	* );
	*/
	public function add_plugin_menu()
	{
		add_options_page(
			'Editor Inline Code',
			'Editor Inline Codee',
			'manage_options',
			'eic_settings',
			array( $this, 'create_admin_page' )
		);
	}

	/**
	*  page_ini
	*
	*  Initialize the setting page.
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	none
	*  @return	void
	*
	* Register the settings ( for input value check ).
	* register_setting(
	* 	$option_group, // setting froup name
	* 	$option_name, // setting name ( save name for db  )
	* 	$sanitize // function name for sanitize
	* );
	*
	* Add section
	* add_settings_section(
	* 	$id, // section id
	* 	$title, // section name
	* 	$function, // function name for output about section description et
	* 	$page // setting page slug ( same as $menu_slug in add_menu_page() )
	* );
	*
	* Add field
	* add_settings_field(
	* 	$id, // input id
	* 	$title, // input name
	* 	$function, // function name for output about input HTML
	* 	$page, // setting page slug ( same as $menu_slug in add_menu_page() )
	* 	$section, // section id ( same as $id in add_settings_section() )
	* 	$args // $function for additional arguments
	* );
	*/
	public function page_init()
	{
		// add setting page
		register_setting(
			'eic_settings',
			'eic_settings',
			array( $this, 'sanitize' )
		);

		// add section
		add_settings_section(
			'eic_def_sec_general',
			__( 'Setting', 'editor-inline-code' ),// 設定
			'',
			'eic_settings'
		);
		add_settings_section(
			'eic_def_sec_front_code',
			__( 'Front Display Setting (code)', 'editor-inline-code' ),// フロント画面 表示設定（コード）
			'',
			'eic_settings'
		);
		add_settings_section(
			'eic_def_sec_front_toolbar',
			__( 'Front Display Setting (toolbar)', 'editor-inline-code' ),// フロント画面 表示設定（ツールバー）
			'',
			'eic_settings'
		);
		add_settings_section(
			'eic_def_sec_editor',
			__( 'Admin Editor Setting', 'editor-inline-code' ),// 管理画面 エディタ設定
			'',
			'eic_settings'
		);
		/* add_settings_section(
			'eic_def_sec_tinymce',
			__( 'TinyMCE Setting', 'editor-inline-code' ),// TinyMCE 設定
			'',
			'eic_settings'
		); */

		// add field
		// Section : Setting
			// Field : theme : selectbox ( select single )
			add_settings_field(
				'eic_def_theme',
				__( 'Theme', 'editor-inline-code' ),// テーマ
				array( $this, 'input_field_theme' ),
				'eic_settings',
				'eic_def_sec_general'
			);
			// Field : lang ; checkbox ( array select multiple )
			add_settings_field(
				'eic_def_langs',
				__( 'Language', 'editor-inline-code' ),// 言語
				array( $this, 'input_field_langs' ),
				'eic_settings',
				'eic_def_sec_general'
			);
		// Section : Setting for Front display
			// Field : display line number : checkbox ( true or false )
			// default : true
			add_settings_field(
				'eic_def_s_code_lnumber',
				__( 'Show Line-Number', 'editor-inline-code' ),// 行番号の表示
				array( $this, 'input_field_s_code_lnumber' ),
				'eic_settings',
				'eic_def_sec_front_code'
			);
			// Field : display invisibles : checkbox ( true or false )
			// default : true
			add_settings_field(
				'eic_def_s_code_invisibles',
				__( 'Show Invisibles', 'editor-inline-code' ),// 空白・改行の表示
				array( $this, 'input_field_s_code_invisibles' ),
				'eic_settings',
				'eic_def_sec_front_code'
			);
		// Section : Setting for Front display ( Toolbar )
			// Field : display lang : checkbox ( true or false )
			// default : true
			add_settings_field(
				'eic_def_s_tool_lang',
				__( 'Show Language', 'editor-inline-code' ),// 言語の表示
				array( $this, 'input_field_s_tool_lang' ),
				'eic_settings',
				'eic_def_sec_front_toolbar'
			);
			// Field : display file name : checkbox ( true or false )
			// default : true
			/* add_settings_field(
				'eic_def_s_tool_file',
				__( 'Show Filename', 'editor-inline-code' ),// ファイル名の表示
				array( $this, 'input_field_s_tool_file' ),
				'eic_settings',
				'eic_def_sec_front_toolbar'
			); */
			// Field : display toolbar : checkbox ( true or false )
			// default : true
			add_settings_field(// show toolbar always
				'eic_def_s_toolbar',
				__( 'Show Toolbar', 'editor-inline-code' ),// ツールバーの表示
				array( $this, 'input_field_s_toolbar' ),
				'eic_settings',
				'eic_def_sec_front_toolbar'
			);
			// Field : display line number : checkbox ( true or false )
			// default : true
			add_settings_field(// toolbar styles plugin style
				'eic_def_toobar_style',
				__( 'Toolbar Style', 'editor-inline-code' ),// ツールバーのスタイル
				array( $this, 'input_field_toobar_style' ),
				'eic_settings',
				'eic_def_sec_front_toolbar'
			);
		// Section : Setting for Admin Editor display
			// Field : display toolbar button : checkbox ( true or false )
			// default : true
			add_settings_field(
				'eic_def_s_editor_toobar',
				__( 'Show Default Button', 'editor-inline-code' ),// デフォルトボタンの表示
				array( $this, 'input_field_s_editor_toobar' ),
				'eic_settings',
				'eic_def_sec_editor'
			);
			// Field : display original button : checkbox ( true or false )
			// default : true
			/* add_settings_field(
				'eic_def_s_editor_ctbtn',
				__( 'Show Custom Button', 'editor-inline-code' ),// カスタムボタンの表示
				array( $this, 'input_field_s_editor_ctbtn' ),
				'eic_settings',
				'eic_def_sec_editor'
			); */
	}

	/**
	*  create_admin_page
	*
	*  Output option page
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	none
	*  @return	void
	*
	*/
	public function create_admin_page()
	{
		// for setting
		wp_enqueue_style(
			'eic-settings',
			$this->op['css']['url'],
			'',
			'1.0',
			'all'
		);
		?>
		<div class="wrap">
			<?php screen_icon(); ?>
			<h2>Editor Inline Code</h2>
			<?php
			global $parent_file;
			if ( $parent_file != 'options-general.php' ) {
				require( ABSPATH . 'wp-admin/options-head.php' );
			}
			?>
			<form method="post" action="options.php">
			<?php
				// output ( same as $option_group in register_setting() )
				settings_fields( 'eic_settings' );
				// output input field ( same as setting page slug  )
				do_settings_sections( 'eic_settings' );
				// output submit button
				submit_button();
			?>
			</form>
		</div>
		<?php
	}

	/**
	*  Output Input Field
	*/

		/**
		*  input_field_theme
		*
		*  Output Input Field for Select Prism Theme
		*
		*  @type	function
		*  @date
		*  @since	1.0.0
		*
		*  @param	none
		*  @return	void
		*
		*/
		public function input_field_theme()
		{
			// get value
			$theme = isset( $this->options['eic_def_theme'] ) ? $this->options['eic_def_theme'] : 'prism';
			?>
			<select name="eic_settings[eic_def_theme]" id="eic_def_theme">
				<option value="prism" <?php selected( 'prism', $theme ); ?>>
					Default
				</option>
				<option value="prism-dark" <?php selected( 'prism-dark', $theme ); ?>>
					Dark
				</option>
				<option value="prism-funky" <?php selected( 'prism-funky', $theme ); ?>>
					Funky
				</option>
				<option value="prism-okaidia" <?php selected( 'prism-okaidia', $theme ); ?>>
					Okadia
				</option>
				<option value="prism-twilight" <?php selected( 'prism-twilight', $theme ); ?>>
					Twilight
				</option>
				<option value="prism-coy" <?php selected( 'prism-coy', $theme ); ?>>
					Coy
				</option>
				<option value="prism-solarizedlight" <?php selected( 'prism-solarizedlight', $theme ); ?>>
					Solarized Light
				</option>
			</select>
			<?php
		}
		/**
		*  input_field_langs
		*
		*  Output Input Field for Select Prism Language
		*
		*  @type	function
		*  @date
		*  @since	1.0.0
		*
		*  @param	none
		*  @return	void
		*
		*/
		public function input_field_langs()
		{
			// get all language lists
			$all_lang_lists = $this->get_lang_lists();
			?>
			<ul class="eic-list-01">
			<?php
			foreach ( $all_lang_lists as $key => $values ) {
				$title = esc_html( $values['title'] );
				$id_name = esc_attr( 'eic_def_langs_'.$key );

				if ( isset($this->options['eic_def_langs']) && in_array($key, $this->options['eic_def_langs']) )
				{
					$value = esc_attr( $key );
				} else {
					$value = '';
				}
				?>
				<li>
					<label for="<?php echo $id_name; ?>">
						<input type="checkbox" id="<?php echo $id_name; ?>" name="eic_settings[eic_def_langs][]" value="<?php echo esc_attr( $key ); ?>" <?php checked( $key, $value ); ?>>
						<?php echo $title; ?>
					</label>
				</li>
				<?php
			}// foreach
			?>
			</ul>
			<?php
		}
		/**
		*  input_field_s_code_lnumber
		*
		*  Output Input Field for display line number
		*
		*  @type	function
		*  @date
		*  @since	1.0.0
		*
		*  @param	none
		*  @return	void
		*
		*/
		public function input_field_s_code_lnumber()
		{
			if ( !empty( $this->options['eic_def_s_code_lnumber'] ) )
			{
				$value = $this->options['eic_def_s_code_lnumber'];
			} else {
				$value = '';
			}
			?>
			<input type="checkbox" id="eic_def_s_code_lnumber" name="eic_settings[eic_def_s_code_lnumber]" <?php checked( 'on', $value ); ?>>
			<?php
		}
		/**
		*  input_field_s_code_invisibles
		*
		*  Output Input Field for display invisibles
		*
		*  @type	function
		*  @date
		*  @since	1.0.0
		*
		*  @param	none
		*  @return	void
		*
		*/
		public function input_field_s_code_invisibles()
		{
			if ( !empty( $this->options['eic_def_s_code_invisibles'] ) )
			{
				$value = $this->options['eic_def_s_code_invisibles'];
			} else {
				$value = '';
			}
			?>
			<input type="checkbox" id="eic_def_s_code_invisibles" name="eic_settings[eic_def_s_code_invisibles]" <?php checked( 'on', $value ); ?>>
			<?php
		}
		/**
		*  input_field_s_tool_lang
		*
		*  Output Input Field for display language
		*
		*  @type	function
		*  @date
		*  @since	1.0.0
		*
		*  @param	none
		*  @return	void
		*
		*/
		public function input_field_s_tool_lang()
		{
			if ( !empty( $this->options['eic_def_s_tool_lang'] ) )
			{
				$value = $this->options['eic_def_s_tool_lang'];
			} else {
				$value = '';
			}
			?>
			<input type="checkbox" id="eic_def_s_tool_lang" name="eic_settings[eic_def_s_tool_lang]" <?php checked( 'on', $value ); ?>>
			<?php
		}
		/**
		*  input_field_s_tool_file
		*
		*  Output Input Field for display filename
		*
		*  @type	function
		*  @date
		*  @since	1.0.0
		*
		*  @param	none
		*  @return	void
		*
		*/
		public function input_field_s_tool_file()
		{
			if ( !empty( $this->options['eic_def_s_tool_file'] ) )
			{
				$value = $this->options['eic_def_s_tool_file'];
			} else {
				$value = '';
			}
			?>
			<input type="checkbox" id="eic_def_s_tool_file" name="eic_settings[eic_def_s_tool_file]" <?php checked( 'on', $value ); ?>>
			<?php
		}
		/**
		*  input_field_s_toolbar
		*
		*  Output Input Field for show toolbar always
		*
		*  @type	function
		*  @date
		*  @since	1.0.0
		*
		*  @param	none
		*  @return	void
		*
		*/
		public function input_field_s_toolbar()
		{
			if ( !empty( $this->options['eic_def_s_toolbar'] ) )
			{
				$value = $this->options['eic_def_s_toolbar'];
			} else {
				$value = '';
			}
			?>
			<input type="checkbox" id="eic_def_s_toolbar" name="eic_settings[eic_def_s_toolbar]" <?php checked( 'on', $value ); ?>> <?php _e( 'always display the toolbar', 'editor-inline-code' );// ツールバーを常に表示する ?>
			<?php
		}
		/**
		*  input_field_toobar_style
		*
		*  Output Input Field for plugin style on toolbar
		*
		*  @type	function
		*  @date
		*  @since	1.0.0
		*
		*  @param	none
		*  @return	void
		*
		*/
		public function input_field_toobar_style()
		{
			// 値を取得
			if ( !empty( $this->options['eic_def_toobar_style'] ) )
			{
				$value = $this->options['eic_def_toobar_style'];
			} else {
				$value = '';
			}
			?>
			<input type="checkbox" id="eic_def_toobar_style" name="eic_settings[eic_def_toobar_style]" <?php checked( 'on', $value ); ?>> <?php _e( 'apply plugin style', 'editor-inline-code' );// プラグインのスタイルを適用する ?>
			<?php
		}
		/**
		*  input_field_s_editor_tooba
		*
		*  Output Input Field for tollbar button
		*
		*  @type	function
		*  @date
		*  @since	1.0.0
		*
		*  @param	none
		*  @return	void
		*
		*/
		public function input_field_s_editor_toobar()
		{
			if ( !empty( $this->options['eic_def_s_editor_toobar'] ) )
			{
				$value = $this->options['eic_def_s_editor_toobar'];
			} else {
				$value = '';
			}
			?>
			<input type="checkbox" id="eic_def_s_editor_toobar" name="eic_settings[eic_def_s_editor_toobar]" <?php checked( 'on', $value ); ?>>
			<?php
		}
		/**
		*  input_field_s_editor_ctbtn
		*
		*  Output Input Field for plugin original button
		*
		*  @type	function
		*  @date
		*  @since	1.0.0
		*
		*  @param	none
		*  @return	void
		*
		*/
		public function input_field_s_editor_ctbtn()
		{
			if ( !empty( $this->options['eic_def_s_editor_ctbtn'] ) )
			{
				$value = $this->options['eic_def_s_editor_ctbtn'];
			} else {
				$value = '';
			}
			?>
			<input type="checkbox" id="eic_def_s_editor_ctbtn" name="eic_settings[eic_def_s_editor_ctbtn]" <?php checked( 'on', $value ); ?>>
			<?php
		}

	/**
	*  Sanitize each setting field as needed
	*/

		/**
		*  sanitize
		*
		*  Check submit(input) value
		*
		*  @type	function
		*  @date
		*  @since	1.0.0
		*
		*  @param	$input(array) input value
		*  @return	void
		*
		*/
		public function sanitize( $input )
		{
			// Toolbar plugin style output input field
			$new_input = array();

			// Theme
			if( isset( $input['eic_def_theme'] ) && trim( $input['eic_def_theme'] ) !== '' ) {
				$new_input['eic_def_theme'] = $this->sanitize_selectbox_single( $input['eic_def_theme'], $this->theme_values );

			} else {
				add_settings_error(
					'eic_settings',
					'eic_def_theme',
					__( 'Please select a theme.', 'editor-inline-code' )
				);
				// Return the value to the DB setting value.
				$new_input['eic_def_theme'] = isset( $this->options['eic_def_theme'] ) ? $this->options['eic_def_theme'] : '';
			}// if

			// language
			if ( isset($input['eic_def_langs']) )
			{
				// get all language lists
				$all_lang_lists = $this->get_lang_lists();;
				// input option values
				$values = $input['eic_def_langs'];

				foreach ( $values as $value ) {
					$new_input['eic_def_langs'][] = $this->sanitize_check_value_arraykey( $value, $all_lang_lists );
				}// foreach
			} else {
				add_settings_error(
					'eic_settings',
					'eic_def_langs',
					__( 'Please check the language to use.', 'editor-inline-code' )
				);
			}// if

			// line number
			if( isset($input['eic_def_s_code_lnumber']) )
			{
				$new_input['eic_def_s_code_lnumber'] = $this->sanitize_checkbox_true_or_false( $input['eic_def_s_code_lnumber'] );
			}// if

			// invisibles
			if ( isset($input['eic_def_s_code_invisibles']) )
			{
				$new_input['eic_def_s_code_invisibles'] = $this->sanitize_checkbox_true_or_false( $input['eic_def_s_code_invisibles'] );
			}// if

			// language
			if ( isset($input['eic_def_s_tool_lang']) )
			{
				$new_input['eic_def_s_tool_lang'] = $this->sanitize_checkbox_true_or_false( $input['eic_def_s_tool_lang'] );
			}// if

			// filename
			if ( isset($input['eic_def_s_tool_file']) )
			{
				$new_input['eic_def_s_tool_file'] = $this->sanitize_checkbox_true_or_false( $input['eic_def_s_tool_file'] );
			}// if

			// show always
			if ( isset($input['eic_def_s_toolbar']) )
			{
				$new_input['eic_def_s_toolbar'] = $this->sanitize_checkbox_true_or_false( $input['eic_def_s_toolbar'] );
			}// if

			// style plugin's style
			if ( isset($input['eic_def_toobar_style']) )
			{
				$new_input['eic_def_toobar_style'] = $this->sanitize_checkbox_true_or_false( $input['eic_def_toobar_style'] );
			}// if

			// toolber button in editor
			if ( isset($input['eic_def_s_editor_toobar']) )
			{
				$new_input['eic_def_s_editor_toobar'] = $this->sanitize_checkbox_true_or_false( $input['eic_def_s_editor_toobar'] );
			}// if

			// plugin's button in editor
			if ( isset($input['eic_def_s_editor_ctbtn']) )
			{
				$new_input['eic_def_s_editor_ctbtn'] = $this->sanitize_checkbox_true_or_false( $input['eic_def_s_editor_ctbtn'] );
			}// if

			return $new_input;
		}// function

			// select single value for radio & selectbox
			private function sanitize_selectbox_single( $value, $array )
			{
				$value = sanitize_text_field( $value );
				if( ! in_array( $value, $array ) ) {
					wp_die( 'Invalid value, go back and try again.' );
				}
				return $value;
			}// function
			// check match value for checkbox
			private function sanitize_check_value( $value, $check_value )
			{
				$value = sanitize_text_field( $value );
				if ( $value !== $check_value )
				{
					wp_die( 'Invalid value, go back and try again.' );
				}
				return $value;
			}
			// check value for checkbox. true or false
			private function sanitize_checkbox_true_or_false( $value )
			{
				// if checked string 'on'
				if ( trim( $value ) !== '' )
				{
					$value = sanitize_text_field( $value );
				}

				if ( $value === 'on' )
				{
					return $value;
				} else if ( $value === true || $value === 'true' ) {
					return 'on';
				} else {
					return '';
				}
			}
			// check value for checkbox. same as array key
			private function sanitize_check_value_arraykey( $value, $array )
			{
				$value = sanitize_text_field( $value );

				if ( !array_key_exists($value, $array) ) {
					wp_die( 'Invalid value, go back and try again.' );
				}
				return $value;
			}


	/**
	*  do_save_options
	*
	*  Process when saving
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	$old_value(array) before values
	*  @param	$value(array) new submit values
	*  @return	void
	*
	*/
	public function do_save_options( $old_value, $value )
	{
		// prism file path
		$lang_dir = $this->src['prism']['langs'];
		$plugin_dir = $this->src['prism']['plugins'];
		$theme_dir = $this->src['prism']['themes'];
		$dist_dir = $this->dist['path'];

		// array to store files
		$css_files =  array();
		$js_files =  array();

		// get option value
			// show line number
			$old_ln = $old_value['eic_def_s_code_lnumber'];
			$new_ln = $value['eic_def_s_code_lnumber'];
			// show invisibles
			$old_si = $old_value['eic_def_s_code_invisibles'];
			$new_si = $value['eic_def_s_code_invisibles'];
			// show lang for front toolbar
			$old_sl = $old_value['eic_def_s_tool_lang'];
			$new_sl = $value['eic_def_s_tool_lang'];
			// show always front toolbar
			$old_tool_always = $old_value['eic_def_s_toolbar'];
			$new_tool_always = $value['eic_def_s_toolbar'];
			// change front toolbar style
			$old_tool_style = $old_value['eic_def_toobar_style'];
			$new_tool_style = $value['eic_def_toobar_style'];

		// All Common
			// css theme
			$old_theme = $old_value['eic_def_theme'];
			$new_theme = $value['eic_def_theme'];
			$theme_css = '';
			if ( $new_theme !== '' )
			{
				$theme_css = $new_theme;
			} else if ( $new_sl === 'on' || $new_ln === 'on' || $new_si === 'on' || $new_tool_always === 'on' || $new_tool_style === 'on' )
			{// If either is on, css is required
				$theme_css = $old_theme;
			}
			$css_files[] = $theme_dir.$theme_css.'.css';
			// default clipboard. clipboard.js
			$js_files[] = $this->src['clipboard']['js']['path'];
			// default prism core file
			$js_files[] = $this->src['prism']['core'];

			// language
			$all_lang_lists = $this->get_lang_lists();
			$old_langs = $old_value['eic_def_langs'];
			$new_langs = $value['eic_def_langs'];
			foreach ( $new_langs as $key ) {
				$js_file = $lang_dir.$all_lang_lists[$key]['value'].'.min.js';
				$js_files[] = $js_file;
			}// foreach

			// prism plugins
				// Required by default clipboard
				$toolbar_dir = 'toolbar';
				$toolbar_filename = 'prism-'.$toolbar_dir;
				$css_files[] = $plugin_dir.$toolbar_dir.'/'.$toolbar_filename.'.css';
				$js_files[] = $plugin_dir.$toolbar_dir.'/'.$toolbar_filename.'.min.js';
				// show lang for front toolbar.
				// Described before the clipboard to display on the left of the clipboard.
				$sl_dir = 'show-language';
				$sl_filename = 'prism-'.$sl_dir;
				if ( $new_sl === 'on' )
				{
					$css_files[] = $plugin_dir.$sl_dir.'/'.$sl_filename.'.css';
					$js_files[] = $plugin_dir.$sl_dir.'/'.$sl_filename.'.min.js';
				}
				// copy-to-clipboard
				$copy_dir = 'copy-to-clipboard';
				$copy_filename = 'prism-'.$copy_dir;
				$js_files[] = $plugin_dir.$copy_dir.'/'.$copy_filename.'.min.js';

		// Add by option values
			// line number
			$ln_dir = 'line-numbers';
			$ln_filename = 'prism-'.$ln_dir;
			if ( $new_ln === 'on' )
			{
				$css_files[] = $plugin_dir.$ln_dir.'/'.$ln_filename.'.css';
				$js_files[] = $plugin_dir.$ln_dir.'/'.$ln_filename.'.min.js';
			}
			// invisibles
			$si_dir = 'show-invisibles';
			$si_filename = 'prism-'.$si_dir;
			if ( $new_si === 'on' )
			{
				$css_files[] = $plugin_dir.$si_dir.'/'.$si_filename.'.css';
				$js_files[] = $plugin_dir.$si_dir.'/'.$si_filename.'.min.js';
			}
			// show filename
			// dir for plugin's css
			// show always gor front toolbar
			if ( $new_tool_always === 'on' )
			{
				$css_files[] = $this->src['tec']['always']['path'];
			}
			// original css for front toolbar
			if ( $new_tool_style === 'on' )
			{
				$css_files[] = $this->src['tec']['styles']['path'];
			}

		// css
		$this->do_combine_files( $css_files, $this->prism['css']['path'] );
		// css 圧縮
		$this->do_minify_css( $this->prism['css']['path'] );
		// js
		$this->do_combine_files( $js_files, $this->prism['js']['path'] );

		// update default file flag
		// if chenge first time
		if ( get_option('eic_default') === '1' )
		{
			update_option( 'eic_default', '0' );
		}
	}




	/* *********************************************
		Main Process
	********************************************* */

	/**
	*  add_mce_buttons
	*
	*  TinyMCE Add Button for first line.
	*
	*  @type function
	*  @date
	*  @since	1.0.0
	*
	*  @param	$buttons(Array). button
	*  @return	(Array). new button
	*/
	public function add_mce_buttons( $buttons ) {
		if ( ! isset($this->options['eic_def_s_editor_toobar']) )
		{
			return;
		}

		$add = array(
			'codesample'
		);
		return array_merge( $buttons, $add );
	}

	/**
	*  tinymce_settings
	*
	*  TinyMCE Setteings. & Main Function
	*
	*  @type function
	*  @date
	*  @since	1.0.0
	*
	*  @param	$int(Array). Current TinyMCE Settings data.
	*  @return	$int(Array). New TinyMCE Settings data.
	*/
	public function tinymce_settings ( $int )
	{
		global $post_id;
		global $hook_suffix;

		// only use admin area & post.php, post-new.php
		if ( is_admin() && !in_array($hook_suffix, array( "post-new.php", "post.php" )) )
		{
			return;
		}

		// get option values
		$options = $this->options;

		// roop tinymce plugins
		/* if ( ! isset($this->tinymce['load_plugins']) )
		{
			return;
		} */
		$plugins = $this->tinymce['load_plugins'];
		foreach ( $plugins as $value ) {
			// set plugins
			$int['plugins'] = $this->get_tinymce_str_value( $int['plugins'], $value );
		}// foreach

		// lang
		if ( isset($options['eic_def_langs']) )
		{
			$all_lang_lists = $this->get_lang_lists();
			$lang_lists = $options['eic_def_langs'];
			$codesample_languages = array();
			foreach ( $lang_lists as $key ) {
				$langs = array();
				$langs['text'] = $all_lang_lists[$key]['title'];
				$langs['value'] = $key;
				$codesample_languages[] = $langs;
			}// foreach
		}// if

		// codesample_languages
		$int['codesample_languages'] = json_encode( $codesample_languages );
		// codesample_dialog_width
		$dialog_width = apply_filters( 'eic_code_dialog_width', '' );
		if( ! empty($dialog_width) )
		{
			$int['codesample_dialog_width'] = $dialog_width;
		}// if
		// codesample_dialog_height
		$dialog_heigh = apply_filters( 'eic_code_dialog_heigh', '' );
		if( ! empty($dialog_heigh) )
		{
			$int['codesample_dialog_heigh'] = $dialog_heigh;
		}// if
		// codesample_content_css by option setting
		if ( get_option('eic_default') === '0' )
		{// set option css
			$codesample_content_css = $this->prism['css']['url'];
		} else {// set default css
			$codesample_content_css = $this->default['css']['url'];
		}
		$int['codesample_content_css'] = $codesample_content_css;

		return $int;
	}// function




	/* *********************************************
		Functions
	********************************************* */

	/**
	*  get_cs_prism_css
	*
	*  get custom prism output file's name by option settings.
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	none
	*  @return	(string) filename
	*/
	private function get_cs_prism_css()
	{
		$filename = '';
		if ( is_multisite() && !is_main_site() )
		{
			$filename = 'blog-'.get_current_blog_id().'-prism.min.css';
		} else {
			$filename = 'prism.min.css';
		}
		return $filename;
	}

	/**
	*  get_cs_prism_js
	*
	*  get custom prism output file's name by option settings.
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	none
	*  @return	(string) filename
	*/
	private function get_cs_prism_js()
	{
		$filename = '';
		if ( is_multisite() && !is_main_site() )
		{
			$filename = 'blog-'.get_current_blog_id().'-prism.min.js';
		} else {
			$filename = 'prism.min.js';
		}
		return $filename;
	}


	/**
	*  do_combine_files
	*
	*  combine files
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	$files(array) File path to combine files
	*  @param	$new_file(string) output new file path(name)
	*  @return	void
	*
	*/
	private function do_combine_files( $files, $new_file )
	{
		$data = '';
		foreach ( $files as $file ) {
			$data .= file_get_contents( $file );
		}
		file_put_contents( $new_file, $data );
	}// function
	/**
	*  do_minify_css
	*
	*  css compression
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	$file(string) File path to compress
	*  @return	void
	*
	*/
	private function do_minify_css( $file )
	{
		$data = file_get_contents( $file );

		/* remove comments */
		$data = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $data );
		// Remove space after colons
		$data = str_replace(': ', ':', $data);
		/* remove tabs, spaces, newlines, etc. */
		$data = str_replace( array("\r\n", "\r", "\n", "\t", '  ', '    ', '    '), '', $data );

		// dist
		file_put_contents( $file, $data );
	}// function

	/**
	*  delete_dir
	*
	*  Delete all files in a specific directory
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	$dir(string) delete dir path
	*  @return	（true or false）
	*/
	public function delete_dir ( $dir )
	{
		foreach ( glob($dir.'*') as $filename ) {
			unlink( $filename);
		}// foreach
	}

	/**
	*  get_tinymce_str_value
	*
	*  processing string value for tinymce settings.
	*
	*  @type	function
	*  @date
	*  @since	1.0.0
	*
	*  @param	$int (string) use comma separated. now strings.
	*			$value (string) use comma separated. Additional new strings.
	*  @return	$int（string）use comma separated.
	*/
	private function get_tinymce_str_value( $int, $value )
	{
		if( !$int || $int !== '' )
		{// If there is already a value
			$int .= ', '.$value;
		} else {//  there is no value
			$int .= $value;
		}// if
		return $int;
	}// function


	// prism theme lists
	/* public function get_theme_lists()
	{
		$lists = array(
			'default' => array(
				'title' => 'Default',
				'value' => 'prism'
			),
			'dark' => array(
				'title' => 'Dark',
				'value' => 'prism-dark'
			),
			'funky' => array(
				'title' => 'Funky',
				'value' => 'prism-funky'
			),
			'okaidia' => array(
				'title' => 'Okaidia',
				'value' => 'prism-okaidia'
			),
			'twilight' => array(
				'title' => 'Twilight',
				'value' => 'prism-twilight'
			),
			'coy' => array(
				'title' => 'Coy',
				'value' => 'prism-coy'
			),
			'solarizedlight' => array(
				'title' => 'Solarized Light',
				'value' => 'prism-solarizedlight'
			)
		);
		return $lists;
	}
	*/
	// prism language lists
	private function get_lang_lists()
	{
		$lists = array(
			'markup' => array(
				'title' => 'HTML',// 'Markup'
				'value' => 'prism-markup'
			),
			'css' => array(
				'title' => 'CSS',
				'value' => 'prism-css'
			),
			'css-extras' => array(
				'title' => 'CSS Extras',
				'value' => 'prism-css-extras'
			),
			/* 'clike' => array(
				'id' => 'clike',
				'title' => 'C-Like',
				'value' => 'prism-clike'
			), */
			'javascript' => array(
				'title' => 'JavaScript',
				'value' => 'prism-javascript'
			),
			'php' => array(
				'title' => 'PHP',
				'value' => 'prism-php'
			),
			'php-extras' => array(
				'title' => 'PHP Extras',
				'value' => 'prism-php-extras'
			),
			'ruby' => array(
				'title' => 'Ruby',
				'value' => 'prism-ruby'
			),
			'sql' => array(
				'title' => 'SQL',
				'value' => 'prism-sql'
			),
			'c' => array(
				'title' => 'C',
				'value' => 'prism-c'
			),
			/* 'abap' => array(
				'title' => 'ABAP',
				'value' => 'prism-abap'
			),
			'actionscript' => array(
				'title' => 'ActionScript',
				'value' => 'prism-actionscript'
			),
			'ada' => array(
				'title' => 'Ada',
				'value' => 'prism-ada'
			), */
			'apacheconf' => array(
				'title' => 'Apache Configuration',
				'value' => 'prism-apacheconf'
			),
			/* 'apl' => array(
				'title' => 'APL',
				'value' => 'prism-apl'
			), */
			'applescript' => array(
				'title' => 'Applescript',
				'value' => 'prism-applescript'
			),
			'asciidoc' => array(
				'title' => 'AsciiDoc',
				'value' => 'prism-asciidoc'
			),
			'aspnet' => array(
				'title' => 'ASP.NET (C#)',
				'value' => 'prism-aspnet'
			),
			/* 'autoit' => array(
				'title' => 'AutoIt',
				'value' => 'prism-autoit'
			),
			'autohotkey' => array(
				'title' => 'AutoHotkey',
				'value' => 'prism-autohotkey'
			), */
			'bash' => array(
				'title' => 'Bash',
				'value' => 'prism-bash'
			),
			'basic' => array(
				'title' => 'BASIC',
				'value' => 'prism-basic'
			),
			'batch' => array(
				'title' => 'Batch',
				'value' => 'prism-batch'
			),
			/* 'bison' => array(
				'title' => 'Bison',
				'value' => 'prism-bison'
			),
			'brainfuck' => array(
				'title' => 'Brainfuck',
				'value' => 'prism-brainfuck'
			),
			'bro' => array(
				'title' => 'Bro',
				'value' => 'prism-bro'
			), */
			'csharp' => array(
				'title' => 'C#',
				'value' => 'prism-csharp'
			),
			'cpp' => array(
				'title' => 'C++',
				'value' => 'prism-cpp'
			),
			'coffeescript' => array(
				'title' => 'CoffeeScript',
				'value' => 'prism-coffeescript'
			),
			/* 'crystal' => array(
				'title' => 'Crystal',
				'value' => 'prism-crystal'
			),
			'd' => array(
				'title' => 'D',
				'value' => 'prism-d'
			),
			'dart' => array(
				'title' => 'Dart',
				'value' => 'prism-dart'
			), */
			'diff' => array(
				'title' => 'Diff',
				'value' => 'prism-diff'
			),
			'django' => array(
				'title' => 'Django/Jinja2',
				'value' => 'prism-django'
			),
			'docker' => array(
				'title' => 'Docker',
				'value' => 'prism-docker'
			),
			/* 'eiffel' => array(
				'title' => 'Eiffel',
				'value' => 'prism-eiffel'
			),
			'elixir' => array(
				'title' => 'Elixir',
				'value' => 'prism-elixir'
			),
			'erlang' => array(
				'title' => 'Erlang',
				'value' => 'prism-erlang'
			),
			'fsharp' => array(
				'title' => 'F#',
				'value' => 'prism-fsharp'
			),
			'fortran' => array(
				'title' => 'Fortran',
				'value' => 'prism-fortran'
			),
			'gherkin' => array(
				'title' => 'Gherkin',
				'value' => 'prism-gherkin'
			), */
			'git' => array(
				'title' => 'Git',
				'value' => 'prism-git'
			),
			/* 'glsl' => array(
				'title' => 'GLSL',
				'value' => 'prism-glsl'
			), */
			'go' => array(
				'title' => 'Go',
				'value' => 'prism-go'
			),
			/* 'graphql' => array(
				'title' => 'GraphQL',
				'value' => 'prism-graphql'
			),
			'groovy' => array(
				'title' => 'Groovy',
				'value' => 'prism-groovy'
			), */
			'haml' => array(
				'title' => 'Haml',
				'value' => 'prism-haml'
			),
			'handlebars' => array(
				'title' => 'Handlebars',
				'value' => 'prism-handlebars'
			),
			/* 'haskell', => array(
				'id' => 'haskell',
				'title' => 'Haskell',
				'value' => 'prism-haskell'
			),
			'haxe' => array(
				'title' => 'Haxe',
				'value' => 'prism-haxe'
			), */
			'http' => array(
				'title' => 'HTTP',
				'value' => 'prism-http'
			),
			/* 'icon' => array(
				'title' => 'Icon',
				'value' => 'prism-icon'
			),
			'inform7' => array(
				'title' => 'Inform 7',
				'value' => 'prism-inform7'
			), */
			'ini' => array(
				'id' => 'ini',
				'title' => 'Ini',
				'value' => 'prism-ini'
			),
			/* 'j' => array(
				'title' => 'J',
				'value' => 'prism-j'
			), */
			'jade' => array(
				'title' => 'Jade',
				'value' => 'prism-jade'
			),
			'java' => array(
				'title' => 'Java',
				'value' => 'prism-java'
			),
			/* 'jolie' => array(
				'title' => 'Jolie',
				'value' => 'prism-jolie'
			), */
			'json' => array(
				'title' => 'JSON',
				'value' => 'prism-json'
			),
			/* 'julia' => array(
				'title' => 'Julia',
				'value' => 'prism-julia'
			),
			'keyman' => array(
				'title' => 'Keyman',
				'value' => 'prism-keyman'
			),
			'kotlin' => array(
				'title' => 'Kotlin',
				'value' => 'prism-kotlin'
			),
			'latex' => array(
				'title' => 'LaTex',
				'value' => 'prism-latex'
			), */
			'less' => array(
				'title' => 'Less',
				'value' => 'prism-less'
			),
			'livescript' => array(
				'title' => 'LiveScript',
				'value' => 'prism-livescript'
			),
			/* 'lolcode' => array(
				'title' => 'LOLCODE',
				'value' => 'prism-lolcode'
			),
			'lua' => array(
				'title' => 'Lua',
				'value' => 'prism-lua'
			),
			'makefile' => array(
				'title' => 'Makefile',
				'value' => 'prism-makefile'
			), */
			'markdown' => array(
				'title' => 'Markdown',
				'value' => 'prism-markdown'
			),
			/* 'matlab' => array(
				'title' => 'MATLAB',
				'value' => 'prism-matlab'
			),
			'mel' => array(
				'title' => 'MEL',
				'value' => 'prism-mel'
			),
			'mizar' => array(
				'title' => 'Mizar',
				'value' => 'prism-mizar'
			),
			'monkey' => array(
				'id' => 'monkey',
				'title' => 'Monkey',
				'value' => 'prism-monkey'
			),
			'nasm' => array(
				'title' => 'NASM',
				'value' => 'prism-nasm'
			), */
			'nginx' => array(
				'title' => 'nginx',
				'value' => 'prism-nginx'
			),
			/* 'nim' => array(
				'title' => 'Nim',
				'value' => 'prism-nim'
			),
			'nix' => array(
				'title' => 'Nix',
				'value' => 'prism-nix'
			), */
			'objectivec' => array(
				'title' => 'Objective-C',
				'value' => 'prism-objectivec'
			),
			/* 'ocaml' => array(
				'title' => 'OCaml',
				'value' => 'prism-ocaml'
			),
			'oz' => array(
				'title' => 'Oz',
				'value' => 'prism-oz'
			),
			'parigp' => array(
				'title' => 'PARI/GP',
				'value' => 'prism-parigp'
			), */
			'parser' => array(
				'title' => 'Parser',
				'value' => 'prism-parser'
			),
			/* 'pascal' => array(
				'title' => 'Pascal',
				'value' => 'prism-pascal'
			), */
			'perl' => array(
				'title' => 'Perl',
				'value' => 'prism-perl'
			),
			'powershell' => array(
				'title' => 'PowerShell',
				'value' => 'prism-powershell'
			),
			'processing' => array(
				'title' => 'Processing',
				'value' => 'prism-processing'
			),
			/* 'prolog' => array(
				'title' => 'Prolog',
				'value' => 'prism-prolog'
			),
			'properties' => array(
				'title' => '.properties',
				'value' => 'prism-properties'
			),
			'protobuf' => array(
				'title' => 'Protocol Buffers',
				'value' => 'prism-protobuf'
			),
			'puppet' => array(
				'title' => 'Puppet',
				'value' => 'prism-puppet'
			),
			'pure' => array(
				'title' => 'Pure',
				'value' => 'prism-pure'
			), */
			'python' => array(
				'title' => 'Python',
				'value' => 'prism-python'
			),
			/* 'q' => array(
				'title' => 'Q',
				'value' => 'prism-q'
			),
			'qore' => array(
				'title' => 'Qore',
				'value' => 'prism-qore'
			),
			'r' => array(
				'title' => 'R',
				'value' => 'prism-r'
			), */
			'jsx' => array(
				'title' => 'React JSX',
				'value' => 'prism-jsx'
			),
			/* 'reason' => array(
				'title' => 'Reason',
				'value' => 'prism-reason'
			),
			'rest' => array(
				'title' => 'reST (reStructuredText)',
				'value' => 'prism-rest'
			),
			'rip' => array(
				'title' => 'Rip',
				'value' => 'prism-rip'
			),
			'roboconf' => array(
				'title' => 'Roboconf',
				'value' => 'prism-roboconf'
			),
			'rust' => array(
				'title' => 'Rust',
				'value' => 'prism-rust'
			),
			'sas' => array(
				'title' => 'SAS',
				'value' => 'prism-sas'
			), */
			'sass' => array(
				'title' => 'Sass (Sass)',
				'value' => 'prism-sass'
			),
			'scss' => array(
				'title' => 'Sass (Scss)',
				'value' => 'prism-scss'
			),
			'scala' => array(
				'title' => 'Scala',
				'value' => 'prism-scala'
			),
			'scheme' => array(
				'title' => 'Scheme',
				'value' => 'prism-scheme'
			),
			/* 'smalltalk' => array(
				'title' => 'Smalltalk',
				'value' => 'prism-smalltalk'
			), */
			'smarty' => array(
				'title' => 'Smarty',
				'value' => 'prism-smarty'
			),
			'stylus' => array(
				'title' => 'Stylus',
				'value' => 'prism-stylus'
			),
			'swift' => array(
				'title' => 'Swift',
				'value' => 'prism-swift'
			),
			/* 'tcl' => array(
				'title' => 'Tcl',
				'value' => 'prism-tcl'
			),
			'textile' => array(
				'title' => 'Textile',
				'value' => 'prism-textile'
			), */
			'twig' => array(
				'title' => 'Twig',
				'value' => 'prism-twig'
			),
			'typescript' => array(
				'title' => 'TypeScript',
				'value' => 'prism-typescript'
			),
			/* 'verilog' => array(
				'title' => 'Verilog',
				'value' => 'prism-verilog'
			),
			'vhdl' => array(
				'title' => 'VHDL',
				'value' => 'prism-vhdl'
			), */
			'vim' => array(
				'title' => 'vim',
				'value' => 'prism-vim'
			),
			'wiki' => array(
				'title' => 'Wiki markup',
				'value' => 'prism-wiki'
			),
			/* 'xojo' => array(
				'title' => 'Xojo (REALbasic)',
				'value' => 'prism-xojo'
			), */
			'yaml' => array(
				'title' => 'YAML',
				'value' => 'prism-yaml'
			),

		);
		return $lists;
	}




	/* *********************************************
	********************************************* */
	//gets instance
	public static function getInstance()
	{
		if( is_null(self::$instance) )
		{
			self::$instance = new self();
		}
		return self::$instance;
	}
}//class Editor_Inline_Code
// initialize
$editor_inline_code = Editor_Inline_Code::getInstance();


/**
 * eic_uninstallHook
 *
 * Method executed when the plugin is deleted (uninstalled)
 *
 * @return void
*/
function eic_uninstallHook( $network_wide )
{
	$my_plugin = 'editor-inline-code/editor-inline-code.php';

	if ( is_multisite() )
	{
		// Delete option for all site
		$sites = get_sites();
		foreach ( $sites as $site ) {
			// switch blog
			switch_to_blog( $site->blog_id );

				if ( !$network_wide && in_array($my_plugin, get_option('active_plugins')) )
				{// If activate from each blog & not deactive
					// when re-install, still activate. and no option data.
					// do deactive plugin
					deactivate_plugins( plugin_basename( __FILE__ ) );
				}

				if ( get_option('eic_installed') === '1' )
				{
					// Delete option value
					delete_option( 'eic_settings' );
					// Delete default file flag
					delete_option( 'eic_default' );
					// Delete installed flag
					delete_option( 'eic_installed' );
				}
			// return blog
			restore_current_blog();
		}// foreach
	} else {// 削除 通常
		// Delete option value
		delete_option( 'eic_settings' );
		// Delete default file flag
		delete_option( 'eic_default' );
		// Delete installed flag
		delete_option( 'eic_installed' );
	}
}

// class_exists check
endif;

?>
